#
# spec file for package httpie
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _mtime 1730482196
%define _commit 2105caa

%define primary_python python311
%define python_version 3.11

Name:           httpie
Version:        3.2.4
Release:        2.1
Summary:        CLI, cURL-like tool for humans
License:        BSD-3-Clause
Group:          Productivity/Networking/Web/Utilities
URL:            https://httpie.org/
Source:         cli-%{version}.%{_mtime}.%{_commit}.tar.gz
Source1:        http.1
BuildRequires:  %{primary_python}
BuildRequires:  %{primary_python}-Pygments >= 2.5.2
BuildRequires:  %{primary_python}-Werkzeug
BuildRequires:  %{primary_python}-charset-normalizer >= 2.0.0
BuildRequires:  %{primary_python}-defusedxml >= 0.6.0
BuildRequires:  %{primary_python}-multidict >= 4.7.0
BuildRequires:  %{primary_python}-pip
BuildRequires:  %{primary_python}-pytest
BuildRequires:  %{primary_python}-pytest-httpbin >= 0.0.6
BuildRequires:  %{primary_python}-pytest-mock
BuildRequires:  %{primary_python}-requests >= 2.22.0
BuildRequires:  %{primary_python}-requests-toolbelt >= 0.9.1
BuildRequires:  %{primary_python}-responses
BuildRequires:  %{primary_python}-rich >= 9.10.0
BuildRequires:  %{primary_python}-setuptools
BuildRequires:  %{primary_python}-wheel
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       %{primary_python}
Requires:       %{primary_python}-Pygments >= 2.5.2
Requires:       %{primary_python}-charset-normalizer >= 2.0.0
Requires:       %{primary_python}-defusedxml >= 0.6.0
Requires:       %{primary_python}-multidict >= 4.7.0
Requires:       %{primary_python}-pip
Requires:       %{primary_python}-requests >= 2.22.0
Requires:       %{primary_python}-requests-toolbelt >= 0.9.1
Requires:       %{primary_python}-rich >= 9.10.0
Requires:       %{primary_python}-setuptools
Provides:       %{primary_python}-httpie = %{version}
Provides:       python3-httpie = %{version}
Obsoletes:      %{primary_python}-httpie < 2.3.0
Obsoletes:      python3-httpie < 2.3.0
BuildArch:      noarch
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description
HTTPie consists of a single "http" command designed for debugging and
interaction with HTTP servers, RESTful APIs, and web services.

It allows for issuing arbitrary HTTP requests and displays colorized
responses.

%prep
%setup -q -n cli-%{version}.%{_mtime}.%{_commit}
#drop shebang
sed -i -e '/^#!\//, 1d' httpie/__main__.py

%build
export LC_CTYPE=en_US.UTF-8
python%{python_version} setup.py build

%install
export LC_CTYPE=en_US.UTF-8
python%{python_version} setup.py install --root=%{buildroot}
%fdupes %{buildroot}%{_prefix}/lib/python%{python_version}/site-packages
install -D -m 0644 %{SOURCE1} %{buildroot}%{_mandir}/man1/http.1
mkdir -p %{buildroot}%{_datadir}/bash-completion/completions
# Install bash & fish completion, credit to Fedora for providing this: https://src.fedoraproject.org/rpms/httpie/blob/rawhide/f/httpie.spec
cp -a extras/httpie-completion.bash %{buildroot}%{_datadir}/bash-completion/completions/http
ln -s ./http %{buildroot}%{_datadir}/bash-completion/completions/https
mkdir -p %{buildroot}%{_datadir}/fish/vendor_completions.d/
cp -a extras/httpie-completion.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/http.fish
ln -s ./http.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/https.fish

%check
export LC_CTYPE=en_US.UTF-8
# disable tests that fail on OBS with [Errno -3] Temporary failure in name resolution
# temporarily disable tests that fail with python 3.11
#pytest --deselect=tests/test_uploads.py --deselect=tests/test_plugins_cli.py
pytest --deselect=tests/test_uploads.py --deselect=tests/test_plugins_cli.py --deselect=tests/test_compress.py --deselect=tests/test_binary.py tests -v

%files
%doc AUTHORS.md CHANGELOG.md README.md
%license LICENSE
%{_bindir}/http
%{_bindir}/https
%{_bindir}/%{name}
%{_prefix}/lib/python%{python_version}/site-packages/httpie*
%{_mandir}/man1/http.1%{?ext_man}
%{_mandir}/man1/https.1%{?ext_man}
%{_mandir}/man1/%{name}.1%{?ext_man}
# co-own the entire directory structures, again credit to Fedora: https://src.fedoraproject.org/rpms/httpie/blob/rawhide/f/httpie.spec
%{_datadir}/bash-completion/
%{_datadir}/fish/

%changelog
* Tue Jan 21 2025 Markéta Machová <mmachova@suse.com>
- Drop unneeded build dependencies
  * upstream [dev] section is not needed for us
- Rewrite %%{python_sitelib} in %%files to respect %%primary_python
* Mon Dec 23 2024 Simon Vogl <simon.vogl@gmx.net>
- Change python version back to 3.11 because too many tests fail
  with 3.12 and higher
* Sat Nov 23 2024 Simon Vogl <simon.vogl@gmx.net>
- Update to version 3.2.4
  * Fix default certs loading and unpin requests.
- Update manpage to version 3.2.4
* Wed Jul 10 2024 Simon Vogl <simon.vogl@gmx.net>
- Update to version 3.2.3
  * Fix SSL connections by pinning the requests version to 2.31.0.
  * Make it possible to unset the User-Agent and Accept-Encoding
    request headers.
- Update manpage to version 3.2.3
- Switch to generating tarball directly from git to harden package
  against supply chain attacks
* Fri Jun 23 2023 Simon Vogl <simon.vogl@gmx.net>
- Temporarily disable tests that fail with python 3.11
* Wed Jun 14 2023 Simon Vogl <simon.vogl@gmx.net>
- Enforce building against the primary python version of the
  current OBS project to avoid build errors
* Sat May 20 2023 Simon Vogl <simon.vogl@gmx.net>
- Update to version 3.2.2
  * Major version upgrade, expect API breakage
  * Too many changes since 2.6.0 to list here, for a full changelog
    please visit:
    https://github.com/httpie/httpie/blob/master/CHANGELOG.md
- Disable more tests that fail in OBS
- Update dependencies
- Update fdupes deduplication
- Add bash and fish completion support
* Tue Apr 26 2022 pgajdos@suse.com
- python3-mock is not required for build
* Sun Oct 17 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.6.0
  * Added support for formatting & coloring of JSON bodies
    preceded by non-JSON data (e.g., an XXSI prefix).
  * Added charset auto-detection when `Content-Type` doesn’t
    include it.
  * Added `--response-charset` to allow overriding the response
    encoding for terminal display purposes.
  * Added `--response-mime` to allow overriding the response mime
    type for coloring and formatting for the terminal.
  * Added the ability to silence warnings through using `-q` or
    `--quiet` twice (e.g. `-qq`).
  * Added installed plugin list to `--debug` output.
  * Fixed duplicate keys preservation in JSON data.
* Mon Sep  6 2021 Martin Hauke <mardnh@gmx.de>
- Fix tests
- Update dependencies
- Update to version 2.5.0
  * Added --raw to allow specifying the raw request body without
    extra processing as an alternative to stdin.
  * Added support for XML formatting.
  * Added internal support for file-like object responses to
    improve adapter plugin support.
  * Fixed --continue --download with a single byte to be
    downloaded left.
  * Fixed --verbose HTTP 307 redirects with streamed request body.
  * Fixed handling of session files with Cookie: followed by other
    headers.
- Update to version 2.4.0
  * Added support for --session cookie expiration based on
    Set-Cookie: max-age=<n>.
  * Show a --check-status warning with --quiet as well, not only
    when the output is redirected.
  * Fixed upload with --session.
  * Fixed a missing blank line between request and response.
* Fri Mar 19 2021 Robert Munteanu <rombert@apache.org>
- Disable tests that fail in OBS
* Wed Jan 20 2021 Dirk Müller <dmueller@suse.com>
- update to 2.3.0:
  * Added support for streamed uploads (#201).
  * Added support for multipart upload streaming (#684).
  * Added support for body-from-file upload streaming (http httpbin.org/post @file).
  * Added --chunked to enable chunked transfer encoding (#753).
  * Added --multipart to allow multipart/form-data encoding for non-file --form requests as well.
  * Added support for preserving field order in multipart requests (#903).
  * Added --boundary to allow a custom boundary string for multipart/form-data requests.
  * Added support for combining cookies specified on the CLI and in a session file (#932).
  * Added out of the box SOCKS support with no extra installation (#904).
  * Added --quiet, -q flag to enforce silent behaviour.
  * Fixed the handling of invalid expires dates in Set-Cookie headers (#963).
  * Removed Tox testing entirely (#943).
- drop httpie-adjust-requirements.patch (obsolete)
- drop singlespec packaging. this is a commandline utility, not a
  python module, so building it for multiple versions of python makes
  no sense.
* Tue Aug 18 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.2.0:
  * Added support for custom content types for uploaded files (`#668`_).
  * Added support for ``$XDG_CONFIG_HOME`` (`#920`_).
  * Added support for ``Set-Cookie``-triggered cookie expiration (`#853`_).
  * Added ``--format-options`` to allow disabling sorting, etc. (`#128`_)
  * Added ``--sorted`` and ``--unsorted`` shortcuts for (un)setting all sorting-related ``--format-options``. (`#128`_)
  * Added ``--ciphers`` to allow configuring OpenSSL ciphers (`#870`_).
  * Added ``netrc`` support for auth plugins. Enabled for ``--auth-type=basic``
    and ``digest``, 3rd parties may opt in (`#718`_, `#719`_, `#852`_, `#934`_).
  * Fixed built-in plugins-related circular imports (`#925`_).
* Sat Apr 18 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1.0
  * Added --path-as-is to bypass dot segment (/../ or /./) URL
    squashing.
  * Changed the default value Accept header value for JSON requests
    from application/json, */* to application/json, */*;q=0.5 to
    clearly indicate preference.
  * Fixed --form file upload mixed with redirected stdin error
    handling.
* Tue Mar 31 2020 Matej Cepl <mcepl@suse.com>
- Don't use %%python3_only command, but properly use alternatives.
* Sun Jan 12 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.0
  * Removed Python 2.7 support (Python 3.6+ is now required).
  * Added --offline to allow building an HTTP request and printing
    it but not actually sending it over the network.
  * Replaced the old collect-all-then-process handling of HTTP
    communication with one-by-one processing of each HTTP request
    or response as they become available. This means that you can
    see headers immediately, see what is being send even when the
    request fails, etc.
  * Removed automatic config file creation to avoid concurrency
    issues.
  * Removed the default 30-second connection --timeout limit.
  * Removed Python’s default limit of 100 response headers.
  * Added --max-headers to allow setting the max header limit.
  * Added --compress to allow request body compression.
  * Added --ignore-netrc to allow bypassing credentials from
    .netrc.
  * Added https alias command with https:// as the default scheme.
  * Added $ALL_PROXY documentation.
  * Added type annotations throughout the codebase.
  * Added tests/ to the PyPi package for the convenience of
    downstream package maintainers.
  * Fixed an error when stdin was a closed fd.
  * Improved --debug output formatting.
- Update patch:
  * httpie-adjust-requirements.patch
* Sun Dec 22 2019 Martin Hauke <mardnh@gmx.de>
- Add patch:
  * httpie-adjust-requirements.patch
    Lower requirements for requests and Pygemnts to make it work
    on Leap 15.1
* Tue Aug 27 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.3
  * Fix CVE-2019-10751 (HTTPie is volnerable to Open Redirect that
    allows an attacker to write an arbitrary file with supplied
    filename and content to the current directory, by redirecting
    a request from HTTP to a crafted URL pointing to a server in
    his or hers control.
* Sun Dec 16 2018 mardnh@gmx.de
- Add manpage
* Sat Dec 15 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias from description.
* Wed Dec 12 2018 mardnh@gmx.de
- Cleanup package
- Run tests
- Update to version 1.0.2
  * Fixed tests for installation with pyOpenSSL.
  * Removed external URL calls from tests.
- Update to version 1.0.0
  * Added --style=auto which follows the terminal ANSI color styles.
  * Added support for selecting TLS 1.3 via --ssl=tls1.3
  * Added true/false as valid values for --verify
  * (in addition to yes/no) and the boolean value is case-insensitive.
  * Changed the default --style from solarized to auto
  * Fixed default headers being incorrectly case-sensitive.
  * Removed Python 2.6 support.
* Thu Aug 10 2017 mardnh@gmx.de
- Fix Url
- Update to version 0.9.8
  * Extended auth plugin API.
  * Added exit status code 7 for plugin errors.
  * Added support for curses-less Python installations.
  * Fixed REQUEST_ITEM arg incorrectly being reported as required.
  * Improved CTRL-C interrupt handling.
  * Added the standard exit status code 130 for keyboard interrupts.
- Update to version 0.9.5
  * Added Python 3 as a dependency for Homebrew installations to ensure some of
    the newer HTTP features work out of the box for macOS users (starting with
    HTTPie 0.9.4.).
  * Added the ability to unset a request header with Header:, and send an empty
    value with Header;.
  * Added --default-scheme <URL_SCHEME> to enable things like $ alias https=
    'http --default-scheme=https.
  * Added -I as a shortcut for --ignore-stdin.
  * Added fish shell completion (located in extras/httpie-completion.fish in
    the Github repo).
  * Updated requests to 2.10.0 so that SOCKS support can be added via pip
    install requests[socks].
  * Changed the default JSON Accept header from application/json to application
    /json, */*.
  * Changed the pre-processing of request HTTP headers so that any leading and
    trailing whitespace is removed.
- Update to version 0.9.4
  * Added Content-Type of files uploaded in multipart/form-data requests
  * Added --ssl=<PROTOCOL> to specify the desired SSL/TLS protocol version to
    use for HTTPS requests.
  * Added JSON detection with --json, -j to work around incorrect Content-Type
  * Added --all to show intermediate responses such as redirects (with --follow
    )
  * Added --history-print, -P WHAT to specify formatting of intermediate
    responses
  * Added --max-redirects=N (default 30)
  * Added -A as short name for --auth-type
  * Added -F as short name for --follow
  * Removed the implicit_content_type config option (use "default_options":
    ["--form"] instead)
  * Redirected stdout doesn't trigger an error anymore when --output FILE is
    set
  * Changed the default --style back to solarized for better support of light
    and dark terminals
  * Improved --debug output
  * Fixed --session when used with --download
  * Fixed --download to trim too long filenames before saving the file
  * Fixed the handling of Content-Type with multiple +subtype parts
  * Removed the XML formatter as the implementation suffered from multiple
    issues
- Update to version 0.9.3
  * Changed the default color --style from solarized to monokai
  * Added basic Bash autocomplete support (need to be installed manually)
  * Added request details to connection error messages
  * Fixed 'requests.packages.urllib3' has no attribute 'disable_warnings'
    errors that occurred in some installations
  * Fixed colors and formatting on Windows
  * Fixed --auth prompt on Windows
* Fri Sep 25 2015 robert.munteanu@gmail.com
- Add requirement for python-curses
* Mon Jul 20 2015 aloisio@gmx.com
- Fixed SLE11 build
* Tue May 19 2015 prusnak@opensuse.org
- updated to 0.9.2
* Sun Jun 15 2014 prusnak@opensuse.org
- created package (version 0.8.0)
